@@ -1,7 +1,7 @@
 use crate::util::reencode_float;
 use crate::{
     detect_encoding, tokens::TokenLookup, BodyEncoding, Ck3Date, Ck3Error, Ck3ErrorKind,
-    Extraction, FailedResolveStrategy,
+    Extraction, FailedResolveStrategy, PdsDate
 };
 use jomini::{BinaryTape, BinaryToken, TextWriterBuilder, TokenResolver, WriteVisitor};
 use std::{
@@ -149,20 +149,20 @@ impl Melter {
                         write!(wtr, "{}", x)?;
                         known_number = false;
                     } else if let Some(date) = Ck3Date::from_binary_heuristic(*x) {
-                        wtr.write_date(date)?;
+                        wtr.write_date(date.game_fmt())?;
                     } else {
                         write!(wtr, "{}", x)?;
                     }
                 }
                 BinaryToken::Quoted(x) => {
                     if known_unquote {
-                        wtr.write_unquoted(x.view_data())?;
+                        wtr.write_unquoted(x.as_bytes())?;
                     } else {
-                        wtr.write_quoted(x.view_data())?;
+                        wtr.write_quoted(x.as_bytes())?;
                     }
                 }
                 BinaryToken::Unquoted(x) => {
-                    wtr.write_unquoted(x.view_data())?;
+                    wtr.write_unquoted(x.as_bytes())?;
                 }
                 BinaryToken::F32(x) => wtr.write_f32(*x)?,
                 BinaryToken::F64(x) if !reencode_float_token => {
